@@ -7,7 +7,7 @@ use Carp;
 use Woothee::Util qw/update_map update_category update_version update_os/;
 use Woothee::DataSet qw/dataset/;
 
-our $VERSION = "1.5.0";
+our $VERSION = "1.6.0";
 
 sub challenge_msie {
     my ($ua,$result) = @_;
@@ -76,6 +76,11 @@ sub challenge_safari_chrome { # and Opera(blink)
             return 1;
         }
 
+        #WebView
+        if (index($ua, "wv") > -1) {
+            return 0;
+        }
+
         # Chrome
         $version = $1;
         update_map($result, dataset("Chrome"));
@@ -147,6 +152,15 @@ sub challenge_webview {
         update_map($result, dataset("Webview"));
         return 1;
     }
+    elsif (index($ua, "wv") > -1) { #WebView
+        if ($ua =~ m{Version/([.0-9]+)}o) {
+            $version = $1;
+        }
+
+        update_version($result, $version);
+        update_map($result, dataset("Webview"));
+        return 1;
+    }
 
     return 0;
 }
