@@ -7,7 +7,7 @@ use Carp;
 use Woothee::Util qw/update_map update_category update_version update_os/;
 use Woothee::DataSet qw/dataset/;
 
-our $VERSION = "1.5.0";
+our $VERSION = "1.6.0";
 
 sub challenge_desktoptools {
     my ($ua, $result) = @_;
@@ -61,6 +61,10 @@ sub challenge_http_library {
         $data = dataset("HTTPLibrary");
         $version = "wget";
     }
+    elsif ($ua =~ m{^curl/}o) {
+        $data = dataset("HTTPLibrary");
+        $version = "curl";
+    }
     elsif ($ua =~ m{^(?:libwww-perl|WWW-Mechanize|LWP::Simple|LWP |lwp-trivial)}o) {
         $data = dataset("HTTPLibrary");
         $version = "perl";
